import { InjectionToken } from '@angular/core';
import { NavigatorNode } from '@c8y/ngx-components';
import { AssetNode } from './asset-node';
export declare const ASSET_NAVIGATOR_CONFIG: InjectionToken<AssetNavigatorConfig>;
/**
 * Configuration object of the AssetsNavigatorModule.
 */
export interface AssetNavigatorConfig {
    /**
     * Allows to enable smart groups in the module.
     * Default value: false.
     */
    smartGroups?: boolean;
    /**
     * Expands the root navigator node when the navigator is initialized.
     * Default value: false
     */
    openOnStart?: boolean;
    /**
     * Allows to change the position of the root group in the navigator.
     * The higher the value, the higher the position in navigation.
     * Default value: 2000.
     */
    rootNodePriority?: number;
    /**
     * Allows to drag and drop items in the asset navigator.
     * Default value: true.
     */
    disableDragAndDrop?: boolean;
    /**
     * Allows to override properies of the root group or hide it.
     * Setup examples:
     * - `rootNavigatorNode: true` - shows the default navigator node (default),
     * - `rootNavigatorNode: false` - hides the navigator node,
     * - `rootNavigatorNode: { label: 'New name', ... }` - overrides default navigator node,
     * - `rootNavigatorNode: new NavigatorNode({ label: 'New name', ... })` - overrides default navigator node,
     */
    rootNavigatorNode?: boolean | Partial<NavigatorNode | AssetNode>;
}
