import { ActionBarItem } from './action-bar.model';
import { ActionBarService } from './action-bar.service';
/**
 * A <c8y-action-bar-item> can be added with content projection.
 * It allows to show items in three positions (left, right
 * or more).
 *
 * @example
 * ```html
 * <c8y-action-bar-item [placement]="'right'">
 *   <button class="btn btn-link" (click)="addRandom()"><i c8yIcon="plus-circle"></i> Add random</button>
 * </c8y-action-bar-item>
 * ```
 */
export declare class ActionBarItemComponent implements ActionBarItem {
    private actionBarService;
    /**
     * Where the item should be shown. Use "more" to place
     * it in a dropdown on the right.
     */
    placement: 'left' | 'right' | 'more';
    /**
     * Priority for sorting the list. Higher priority means
     * an earlier position in the list.
     */
    priority: number;
    /**
     * Adds additional classes to the item.
     */
    itemClass: string;
    /**
     * @ignore
     */
    template: any;
    private viewInitTimeout;
    /**
     * @ignore
     */
    constructor(actionBarService: ActionBarService);
    /**
     * @ignore
     */
    ngAfterViewInit(): void;
    /**
     * @ignore
     */
    ngOnDestroy(): void;
}
