import { Action } from './action.model';
import { ActionService } from './action.service';
/**
 * A <c8y-action> can be added with content projection.
 *
 * @example
 * ```html
 * <c8y-action>
 *   <button class="btn" (click)="myAction()">My action</button>
 * </c8y-action>
 * ```
 */
export declare class ActionComponent implements Action {
    private actionService;
    /**
     * Is this action disabled.
     */
    disabled: boolean;
    /**
     * The label of the component
     */
    label: string;
    /**
     * The priority of this action (the higher the number, the higher the action will be displayed; optional)
     */
    priority: number;
    /**
     * The icon to show on this action
     */
    icon: string;
    template: any;
    action: () => void;
    private viewInitTimeout;
    constructor(actionService: ActionService);
    /**
     * After page view is initialized, component adds itself to global action list.
     */
    ngAfterViewInit(): void;
    /**
     * Action is removed from global action list, if component is not used anymore.
     */
    ngOnDestroy(): void;
}
