import { Alert } from './alert.model';
import { AlertService } from './alert.service';
import { BehaviorSubject } from 'rxjs';
/**
 * Alert outlet component shows all added alerts. It is used in the application's `c8y-bootstrap` component.
 *
 * For applications which don’t use `c8y-bootstrap` component but want to display alerts via AlertService, a c8y-alert-outlet component needs to be added explicitly in the template.
 *
 * ## Example:
 * ```html
 *  <div class="alerts">
 *    <c8y-alert-outlet></c8y-alert-outlet>
 *  </div>
 * ```
 */
export declare class AlertOutletComponent {
    private position;
    alertService: AlertService;
    /**
     * Currently displayed details of an alert. Only one alert’s details can be displayed at a time.”
     */
    detailDisplayedAlert: any;
    /**
     * @ignore
     */
    isStatic: boolean;
    /**
     * The array of current alerts.
     */
    get alerts(): BehaviorSubject<Alert[]>;
    /**
     * @ignore
     */
    constructor(position: string, alertService: AlertService);
    /**
     * Returns a CSS class for an alert depending on its type to style the corresponding alert component.
     */
    getClass(alert: Alert): string;
    /**
     * Executes alert’s onClose method, if provided, and closes the alert.
     * @param alert The alert which will be closed.
     */
    close(alert: Alert): void;
    /**
     * Expands details part of particular alert, and collapses details for another alerts.
     * @param alert The alert which details should be expanded.
     */
    showDetails(alert: Alert): void;
    /**
     * Returns true if alert has extra detailedData or defines custom onDetail method.
     */
    hasDetails(alert: Alert): any;
    /**
     * Collapses alert's details.
     */
    closeDetails(): void;
    /**
     * Returns true if details part of alert is expanded.
     */
    isDetailsShow(alert: Alert): boolean;
    /**
     * @ignore
     */
    isTemplateRef(value: any): boolean;
    /**
     * @ignore
     */
    template(content: any): any;
    private setDetailsContent;
}
