import { ExtensionFactory } from '../common/extension-hooks';
/**
 * A crumb of the breadcrumb.
 */
export interface BreadcrumbItem {
    /**
     * The icon to show on this BreadCrumb item.
     * The icon will only be displayed if it is the first crumb. (optional)
     */
    icon?: string;
    /**
     * Should it be translated or not.
     * @todo verify if needed.
     * @deprecated Only needed in upgrade case.
     */
    translate?: boolean;
    /**
     * The label to show for that crumb.
     */
    label: string;
    /**
     * The angular route path to navigate to on click.
     */
    path: string;
    /**
     * Angular template used for Content Projection (optional)
     */
    template?: any;
}
/**
 * One Page can have multiple Breadcrumb paths components.
 * E.g. A device which is in multiple folders.
 */
export interface Breadcrumb {
    /**
     * The crumbs.
     */
    items: BreadcrumbItem[];
}
/**
 * Factory to implement if used in a hook for Multi Provider extension.
 */
export declare type BreadcrumbFactory = ExtensionFactory<Breadcrumb>;
