import { BehaviorSubject } from 'rxjs';
import { StateService } from './state-service.abstract';
import { OptionsService } from './options.service';
import { FetchClient, TenantLoginOptionsService } from '@c8y/client';
import { ApplicationService, IUser, ICurrentTenant } from '@c8y/client';
import { ApiService } from '@c8y/ngx-components/api';
export declare class AppStateService extends StateService {
    private applicationService;
    apiService: ApiService;
    private options;
    private fetchClient;
    private tenantLoginOptionsService;
    state$: BehaviorSubject<any>;
    currentSupportUserName: BehaviorSubject<string | null>;
    currentUser: BehaviorSubject<IUser | null>;
    currentTenant: BehaviorSubject<ICurrentTenant | null>;
    constructor(applicationService: ApplicationService, apiService: ApiService, options: OptionsService, fetchClient: FetchClient, tenantLoginOptionsService: TenantLoginOptionsService);
    assignApplicationKeyToDefaultHeaders(): void;
    /**
     * Returns the current state.
     */
    get state(): any;
    getLangs(): any;
    /**
     * Returns the correct UI version. In hybrid mode for angular and ngx.
     */
    get uiVersion(): any;
    /**
     * Loads the app manifest. If no access -> throw an error to verify app access.
     */
    loadManifest(): Promise<void>;
    /**
     * When this function called, it refreshes the values of loginOptions stored within ui state object.
     * Function is throttled to execute the refresh once in a time specified by params of @throttled decorator,
     * it should be called on leading edge of the timeout.
     */
    refreshLoginOptions(): Promise<void>;
    /**
     * Checks current users application list and matches it against given application name.
     * Returns true if application is in the list.
     * @param name application name
     */
    isApplicationAvailable(name: string): Promise<boolean>;
    /**
     * Sets current user (including support user).
     * @param userInfo Info about current user and support user to be set.
     */
    setUser(userInfo: {
        user: IUser;
        supportUserName: string;
    }): void;
    private getCurrentContextPath;
    private loadDefaultOptions;
    private showIncompatibleVersionsError;
}
