import { EventEmitter, OnInit } from '@angular/core';
import { DroppedFile, DropAreaComponent } from '../drop-area/drop-area.component';
import { PickedFiles } from './file-picker.model';
import { FilePickerConfig } from './file-picker-config.model';
/**
 * User can upload a binary directly or use an URL.
 *
 * ## Usage Example:
 *
 * ```html
 * <div>
 * <c8y-file-picker [maxAllowedFiles]="1" (onFilesPicked)="onFile($event)">
 * </c8y-file-picker>
 * </div>
 * ```
 */
export declare class FilePickerComponent implements OnInit {
    dropArea: DropAreaComponent;
    onFilesPicked: EventEmitter<PickedFiles>;
    maxAllowedFiles: number;
    uploadChoice: 'uploadBinary' | 'uploadUrl';
    fileUrl: string;
    fileBinary: DroppedFile;
    config: FilePickerConfig;
    /**
     * Additional string to be displayed in a popover.
     */
    fileUrlPopover: string;
    droppedFiles: DroppedFile[];
    private fileToSave;
    /**
     * @ignore
     */
    ngOnInit(): void;
    /**
     * Triggered by dropped file in component and pass it into drop-area component.
     */
    onFileDropped(droppedFiles: DroppedFile[]): void;
    /**
     * Triggered when user changes upload choice, from upload url to upload binary.
     */
    clearInputFromUrl(): void;
    /**
     * Triggered when user changes upload choice, to avoid cumulation of droppedFiles.
     */
    clearSelectedFiles(): void;
    /**
     * Triggered when user puts binary's url to upload.
     */
    onFileUrlChange(urlStr: any): void;
    /**
     * Checks if there is popover to display.
     */
    isPopoverUsed(): boolean;
}
