import { BehaviorSubject, Observable } from 'rxjs';
import { OptionsService } from '../common/options.service';
import { StateService } from '../common/state-service.abstract';
import { NavigatorService } from '../navigator/navigator.service';
import { Header } from './header.model';
import { HumanizeAppNamePipe } from '../common';
/**
 * A service which defines header functions.
 */
export declare class HeaderService extends StateService {
    private navigatorService;
    private options;
    private humanizeAppName;
    headerOpen: boolean;
    header$: Observable<Header>;
    navigatorOpen$: Observable<boolean>;
    readonly DELAY_TO_AVOID_FLICKERING_ON_ASYNC_NODES = 1000;
    hasItemsInNavigator$: Observable<boolean>;
    state$: BehaviorSubject<Header>;
    title: any;
    constructor(navigatorService: NavigatorService, options: OptionsService, humanizeAppName: HumanizeAppNamePipe);
    get state(): Header;
    get navigatorHiddenOnStartup(): boolean;
    get largeWidth(): boolean;
    get shouldToggle(): boolean;
    /**
     * Toggles the main header menu in mobile view.
     */
    toggle(): void;
    /**
     * Toggles the navigator open status.
     */
    toggleNavigator(): void;
    /**
     * Force to close the navigator.
     */
    closeNavigator(): void;
    /**
     * Configures navigation options.
     * @param config Object with the properties:
     * - open: Boolean
     */
    configNavigator(config?: any): void;
    /**
     * Change the application title.
     * @param newTitle The new title of the application.
     */
    changeTitle(newTitle?: any, pageTitleUpdate?: boolean): void;
    /**
     * Change the page title.
     * @param newTitle The new title of the page.
     */
    changePageTitle(newTitle?: string): void;
    /**
     * This methods checks if the navigator toggles on startup
     * or if an item is added to the navigator node.
     * Delay of 300ms is intended for animation purpose.
     */
    verifyIfNavOpen(): void;
    shouldShowBreadcrumbs(): boolean;
}
