import { TranslateService } from '@ngx-translate/core';
import { AppStateService } from '../common/ui-state.service';
import { DocsService } from '../docs/docs.service';
/**
 * A component which shows a context help in
 * the action bar.
 *
 * @example
 * ```html
 * <c8y-help src="/users-guide/cockpit/#dashboards"></c8y-help>
 * ```
 */
export declare class HelpComponent {
    private docsService;
    private appState;
    private translateService;
    /**
     * The source of the documentation. Used to link to the documentation as well as
     * to parse the source to display.
     */
    src: string;
    /**
     * Indicates if the help dialog is collapsed.
     */
    isCollapsed: boolean;
    /**
     * The priority where the help icon should be shown in the action bar
     */
    priority: number;
    /**
     * An custom icon. If not set, the navigator icon is resolved
     */
    icon: any;
    /**
     * Currrent version of the UI which will be used to get the correct data from
     * the docs. If the UI version is equal to the latest doc version, the value
     * must be ''.
     */
    version: string;
    /**
     * An title. Set in open by passing the source.
     */
    title: string;
    /**
     * The section heading in the doc which is going to be displayed.
     */
    sectionHeading: string;
    /**
     * The section content in the doc which is going to be displayed.
     */
    sectionContent: string;
    /**
     * Indicates if the component is loading.
     */
    isLoading: boolean;
    /**
     * Indicates if the component failed loading the source.
     */
    hasError: boolean;
    private readonly SUPPORTED_LANGUAGES;
    /**
     * Identifies if the current user language is supported
     * Currently only English is supported.
     */
    get isSupportedLanguage(): boolean;
    /**
     * @ignore Only private DI
     */
    constructor(docsService: DocsService, appState: AppStateService, translateService: TranslateService);
    /**
     * Builds the URL based on the src. The Base URL can be set in the application options docBaseUrl.
     * @param src The source of the help on the guide.
     * @param index This flag is used to call the index.json content of a guide. For example, "https://www.cumulocity.com/guides/users-guide/cockpit/index.json".
     */
    getUrl(src?: string, index?: boolean): string;
    /**
     * Toggles the visibility of the help dialog.
     */
    toggle(): void;
    /**
     * Closes the help dialog.
     */
    close(): void;
    /**
     * Opens the help dialog.
     */
    open(): void;
    private requestContent;
    private clean;
    private parseVersion;
    private resolveIcon;
    private render;
}
