import { TranslateService as NgxTranslateService } from '@ngx-translate/core';
import { OptionsService } from '../common/options.service';
import { AppStateService } from '../common/ui-state.service';
/**
 * A service to manage the language of the application.
 */
export declare class TranslateService {
    private ngxTranslate;
    private ui;
    private options;
    static SAVE_LANGUAGE_KEY: string;
    static defaultLang(): string;
    langsDetail: any;
    langs: any;
    private DEFAULT_SEPARATOR;
    constructor(ngxTranslate: NgxTranslateService, ui: AppStateService, options: OptionsService);
    /**
     * Switches to given language.
     * @param lang The language as two-letter code.
     */
    switchToLanguage(lang: string): Promise<void>;
    loadLocales(moduleLang: any): Promise<void>;
    setLanguage(lang: string): void;
    /**
     * Finds the first supported language
     */
    firstSupportedLanguage(): any;
    /**
     * Converts a iso language code to a PO language code (e.g. de-de gets de_de).
     * @param lang The iso language code.
     */
    convertToLanguageCodePO(lang: string): string;
    /**
     * Returns the language in the native language.
     * @param lang The language two-letter code.
     * @return The native name.
     */
    getNativeLanguage(lang: string): string;
    saveInLocalStorage(lang: string): void;
    getSupported(lang: string): any;
    /**
     * Gets the language from the query parameter.
     * @return The language two-letter code.
     */
    queryStringLang(): any;
    private getLessSpecific;
    /**
     * Gets the language from local storage.
     * @return The language two-letter code.
     */
    private localStorageLang;
    /**
     * Determines which language is set in the browser.
     * @return The languages the browser supports as string array.
     */
    private browserLangs;
    private getQueryParameter;
}
