import { EventEmitter } from '@angular/core';
/**
 * Actions are functions that can be executed on the
 * current list item. They are displayed next to the
 * item and can be grouped in a dropdown.
 *
 * @example
 * ```html
 * <c8y-li>
 *   <c8y-li-action (click)="deleteDevice(device.id)" icon="times">
 *     Delete
 *   </c8y-li-action>
 *   <c8y-li-action (click)="(false)" icon="rocket">
 *     Launch to space
 *   </c8y-li-action>
 * </c8y-li>
 * ```
 */
export declare class ListItemActionComponent {
    /**
     * @ignore
     */
    template: any;
    /**
     * The label to display (you can alternatively use
     * content projection to display the label).
     */
    label: string;
    /**
     * The name of the icon to use
     */
    icon: string;
    /**
     * An EventEmitter to determine what to do if the
     * action is triggered.
     */
    click: EventEmitter<any>;
}
