import { ElementRef, EventEmitter, SimpleChanges } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
/**
 * A component to display a radio button in a c8y-li. Use it with content projection. It
 * can be used standalone or with an ngModel.
 *
 * @example
 * ```html
 * <c8y-li>
 *   <c8y-li-radio></c8y-li-radio>
 * </c8y-li>
 * ```
 */
export declare class ListItemRadioComponent implements ControlValueAccessor {
    /**
     * @ignore
     */
    radio: ElementRef;
    /**
     * Indicates if the radio is selected.
     */
    selected: boolean;
    /**
     * The name of the radio (use different names for different radio groups).
     */
    name: string;
    /**
     * Indicates if the radio is disabled.
     */
    disabled: boolean;
    /**
     * An event emitted as soon as the radio is selected.
     */
    onSelect: EventEmitter<boolean>;
    /**
     * The current value.
     */
    value: any;
    /**
     * @ignore
     */
    model: any;
    /**
     * @ignore
     */
    onChange: (value: any) => void;
    /**
     * @ignore
     */
    onTouched: () => void;
    /**
     * Resets the native radio element.
     */
    reset(): void;
    /**
     * @ignore
     */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Triggered when the radio is changed.
     * @param checked Should it be checked or not?
     */
    change(checked: any): void;
    /**
     * Registers an onChange event.
     */
    registerOnChange(fn: any): void;
    /**
     * Registers an onTouch event.
     */
    registerOnTouched(fn: any): void;
    /**
     * @ignore
     */
    writeValue(value: boolean): void;
}
