declare type AcceptedPropertyTypes = string | string[] | number | number[];
export interface PropertiesListItem {
    /**
     * The label to show.
     */
    label: string;
    /**
     * The value to show for this label.
     */
    value?: AcceptedPropertyTypes;
    /**
     * The key to determine the value from an object. You need to provide this object then to the
     * properties-list component as well in the [values] input. Note, you can only either display
     * a value or a key. A key always is preferred over an value.
     */
    key?: string;
    /**
     * The display type of this item.
     */
    type?: 'string' | 'group' | 'array' | 'link';
    /**
     * An action which will be shown as a link on the value.
     */
    action?: (event: any, value: PropertiesListItem) => void;
    /**
     * Allows to transform a value if needed.
     */
    transform?: (value: AcceptedPropertyTypes) => AcceptedPropertyTypes;
}
export {};
