import { ViewContainerRef } from '@angular/core';
import { ExtensionFactory } from '../common/extension-hooks';
/**
 * An tab allows to switch routes
 * on a page.
 */
export interface Tab {
    /**
     * The angular route path to navigate to on click.
     */
    path: string;
    /**
     * The label to show for that tab.
     */
    label: string;
    /**
     * The icon to show on this tab (optional)
     */
    icon?: string;
    /**
     * Ordering of the tabs (high number first) (optional)
     */
    priority?: number;
    /**
     * Angular template used for Content Projection (optional)
     */
    template?: ViewContainerRef;
    /**
     * Alignment for tabs (optional)
     */
    orientation?: 'horizontal' | 'vertical';
    /**
     * Hide tab (optional)
     */
    hide?: boolean;
}
/**
 * Factory to implement if used in a hook for Multi Provider extension.
 */
export declare type TabFactory = ExtensionFactory<Tab>;
