import { Component, Input, NgModule } from '@angular/core';
import { CoreModule } from '@c8y/ngx-components';
import { InventoryService } from '@c8y/client';

class OperationSummaryComponent {
    constructor(inventoryService) {
        this.inventoryService = inventoryService;
        this.deviceCount = 0;
        this.displayDeviceCount = false;
    }
    set deviceQueryString(query) {
        this.displayDeviceCount = true;
        const filters = {
            q: query || '',
            pageSize: 1,
            currentPage: 1,
            withTotalPages: true
        };
        this.inventoryService
            .list(filters)
            .then((result) => (this.deviceCount = result.paging.totalPages));
    }
}
OperationSummaryComponent.decorators = [
    { type: Component, args: [{
                selector: 'c8y-operation-summary',
                template: "<div class=\"row\">\n  <div class=\"col-md-12 text-center\">\n    <p>{{ name | translate }}</p>\n    <div class=\"row\">\n      <div class=\"col-md-4 col-md-offset-4 text-center\">\n        <h4 class=\"m-t-16 m-b-8 text-truncate\" title=\"{{ description | translate }}\">{{ description | translate }}</h4>\n      </div>\n    </div>\n    <span\n      class=\"text-muted\"\n      [ngPlural]=\"deviceCount\"\n      *ngIf=\"displayDeviceCount && deviceCount !== undefined && deviceCount !== null\"\n    >\n      <ng-template ngPluralCase=\"=0\">\n        <span translate>No devices selected</span>\n      </ng-template>\n      <ng-template ngPluralCase=\"=1\">\n        <span translate>1 device selected</span>\n      </ng-template>\n      <ng-template ngPluralCase=\"other\">\n        <span translate ngNonBindable [translateParams]=\"{ deviceCount: deviceCount }\">\n          {{ deviceCount }} devices selected</span\n        >\n      </ng-template>\n    </span>\n  </div>\n</div>\n"
            },] }
];
OperationSummaryComponent.ctorParameters = () => [
    { type: InventoryService }
];
OperationSummaryComponent.propDecorators = {
    name: [{ type: Input }],
    description: [{ type: Input }],
    deviceQueryString: [{ type: Input }]
};

/**
 * This module provides a component for displaying the summary of given bulk operation.
 */
class OperationSummaryModule {
}
OperationSummaryModule.decorators = [
    { type: NgModule, args: [{
                imports: [CoreModule],
                declarations: [OperationSummaryComponent],
                entryComponents: [OperationSummaryComponent],
                exports: [OperationSummaryComponent]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { OperationSummaryComponent, OperationSummaryModule };
//# sourceMappingURL=c8y-ngx-components-operations-operation-summary.js.map
